[Libreoffice-commits] online.git: docker/l10n-docker-nightly.sh

Samuel Mehrbrodt (via logerrit) logerrit at kemper.freedesktop.org
Tue Dec 17 07:24:50 UTC 2019


 docker/l10n-docker-nightly.sh |   12 +++++++++---
 1 file changed, 9 insertions(+), 3 deletions(-)

New commits:
commit 0068d8b2d91ec1b5fc94881822621e22986316fe
Author:     Samuel Mehrbrodt <Samuel.Mehrbrodt at cib.de>
AuthorDate: Tue Dec 17 08:11:14 2019 +0100
Commit:     Samuel Mehrbrodt <Samuel.Mehrbrodt at cib.de>
CommitDate: Tue Dec 17 08:24:32 2019 +0100

    docker: Allow to build different branches in core+online
    
    Change-Id: Ifbd705fc95ae225858ccd582ed2e0150a40f6a93
    Reviewed-on: https://gerrit.libreoffice.org/85254
    Reviewed-by: Samuel Mehrbrodt <Samuel.Mehrbrodt at cib.de>
    Tested-by: Samuel Mehrbrodt <Samuel.Mehrbrodt at cib.de>

diff --git a/docker/l10n-docker-nightly.sh b/docker/l10n-docker-nightly.sh
index c877cbb5c..4bb588823 100755
--- a/docker/l10n-docker-nightly.sh
+++ b/docker/l10n-docker-nightly.sh
@@ -8,7 +8,8 @@
 # -- Available env vars --
 # * DOCKER_HUB_REPO - which Docker Hub repo to use
 # * DOCKER_HUB_TAG  - which Docker Hub tag to create
 # * LIBREOFFICE_BRANCH  - which branch to build (needs to exist in both core and online)
 # * LIBREOFFICE_BUILD_TARGET - which make target to run (in core repo)
 # * ONLINE_EXTRA_BUILD_OPTIONS - extra build options for online
 # * NO_DOCKER_IMAGE - if set, don't build the docker image itself, just do all the preps
@@ -33,7 +34,12 @@ echo "Using Docker Hub Repository: '$DOCKER_HUB_REPO' with tag '$DOCKER_HUB_TAG'
 if [ -z "$LIBREOFFICE_BRANCH" ]; then
   LIBREOFFICE_BRANCH="master"
 fi;
-echo "Building branch '$LIBREOFFICE_BRANCH'"
+echo "Building core branch '$LIBREOFFICE_BRANCH'"
+
+if [ -z "$LIBREOFFICE_ONLINE_BRANCH" ]; then
+  LIBREOFFICE_ONLINE_BRANCH="master"
+fi;
+echo "Building online branch '$LIBREOFFICE_ONLINE_BRANCH'"
 
 if [ -z "$LIBREOFFICE_BUILD_TARGET" ]; then
   LIBREOFFICE_BUILD_TARGET=""
@@ -65,7 +71,7 @@ if test ! -d online ; then
     git clone https://git.libreoffice.org/online online || exit 1
 fi
 
-( cd online && git fetch --all && git checkout -f $LIBREOFFICE_BRANCH && git clean -f -d && git pull -r ) || exit 1
+( cd online && git fetch --all && git checkout -f $LIBREOFFICE_ONLINE_BRANCH && git clean -f -d && git pull -r ) || exit 1
 
 ##### LibreOffice #####
 
@@ -8,7 +8,8 @@
 # * DOCKER_HUB_REPO - which Docker Hub repo to use
 # * DOCKER_HUB_TAG  - which Docker Hub tag to create
-# * LIBREOFFICE_BRANCH  - which branch to build (needs to exist in both core and online)
+# * LIBREOFFICE_BRANCH  - which branch to build in core
+# * LIBREOFFICE_ONLINE_BRANCH - which branch to build in online
 # * LIBREOFFICE_BUILD_TARGET - which make target to run (in core repo)
 # * ONLINE_EXTRA_BUILD_OPTIONS - extra build options for online


More information about the Libreoffice-commits mailing list